#
# spec file for package openstack-monasca-persister-java
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright 2017 Fujitsu LIMITED
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define username          monasca-persister
%define groupname         monasca

%define persister_name    monasca-persister

%define persister_jar_dir %{_datadir}/%{persister_name}
%define persister_cfg_dir %{_sysconfdir}/%{persister_name}
%define persister_log_dir /var/log/%{persister_name}

%define service_name openstack-monasca-persister
%define sname        monasca-persister-java

%define tarball_version 1.4.0

Name:           openstack-%{sname}
Version:        1.2.1
Release:        8.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            https://github.com/openstack/monasca-persister 
Summary:        Consumes metrics and alarm state transitions from message queue
License:        Apache-2.0
Group:          Monitoring/Tools
Source0:        https://tarballs.openstack.org/monasca-persister/monasca-persister-%{tarball_version}.tar.gz
Source1:        %{name}.changes
Source2:        %{service_name}.service
Source3:        %{sname}.yaml
Source4:        build.sh
Patch1:         maven-repo-from-environment.patch
Patch2:         upgrade-to-influxdb-1.1.patch
Patch3:         fix-for-influxdb-1.1.patch
# https://github.com/FujitsuEnablingSoftwareTechnologyGmbH/monasca-persister/commit/23d046761425897772e866ceb1e40c5c91e5b464
Patch4:         0001-Bugfix-Parse-value_meta-information.patch
BuildRequires:  git-core
BuildRequires:  java-1_8_0-openjdk
BuildRequires:  java-1_8_0-openjdk-devel
BuildRequires:  java-monasca-common
BuildRequires:  openstack-macros
BuildRequires:  openstack-monasca-persister-java-kit == %{version}
Requires:       java-1_8_0-openjdk
Provides:       %{sname}
BuildArch:      noarch
Requires(pre):  pwdutils

%description
Consumes metrics and alarm state transitions from
message queue and stores them in database. Data is read from Kafka queue and
saved either in InfluxDB or Cassandra

%prep
%setup -q -c -n src
cp -Rf %{_datadir}/tetra ../kit
cd monasca-persister-%{tarball_version}
# run_maven.sh tries to determine a git revision and for that this needs
# to run in a git repository, so make one...
git init .
git config --global user.email "you@example.com"
git config --global user.name "Your Name"
git add .
git commit -am 'Dummy commit'
%patch1 -p 1
%patch2 -p 1
%patch3 -p 1
%patch4 -p1

%build
export PROJECT_PREFIX=$(readlink -e ..)
export VERSION=%{version}
cd monasca-persister-%{tarball_version}
sh %{SOURCE4}

%install

## usr
%{__install} -d -m 755 %{buildroot}%{_sbindir}
%{__install} -d -m 755 %{buildroot}%{_unitdir}

## etc
%{__install} -d -m 755 %{buildroot}%{persister_cfg_dir}
%{__install} -D -m 644 %{S:3} %{buildroot}%{persister_cfg_dir}/%{persister_name}.yaml

## system stuff
%{__install} -p -D -m 444 %{S:2} %{buildroot}%{_unitdir}/%{service_name}.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{service_name}

## jar stuff
%{__install} -d -m 755 %{buildroot}%{persister_jar_dir}
%{__install} -D -m 644 monasca-persister-%{tarball_version}/java/target/monasca-persister-%{version}-SNAPSHOT-shaded.jar %{buildroot}%{persister_jar_dir}/%{persister_name}.jar

## log dir
%{__install} -d -m 750 %{buildroot}%{persister_log_dir}

## sed me
sed -e "
  s|__PERSISTER_USER__|%{username}|g;
  s|__PERSISTER_GROUP__|%{groupname}|g;
  s|__PERSISTER_JAR__|%{persister_jar_dir}/%{persister_name}.jar|g;
  s|__PERSISTER_CONFIG__|%{persister_cfg_dir}/%{persister_name}.yaml|g;
  s|__PERSISTER_LOGDIR__|%{persister_log_dir}|g;
" -i %{buildroot}%{_unitdir}/%{service_name}.service

sed -e "
  s|__PERSISTER_LOGDIR__|%{persister_log_dir}|g;       
" -i %{buildroot}%{persister_cfg_dir}/%{persister_name}.yaml

%pre
%openstack_pre_user_group_create %{username} %{groupname}

%service_add_pre %{service_name}.service
exit 0

%post
%service_add_post %{service_name}.service

cat <<EOF

Configuration:
================================================================================
Following configuration bits need to be provided prior to running monasca-persister:

- Zookeeper host&port
- Kafka host&port
- TimeBased-DB host&port

================================================================================

Dependencies:
================================================================================
monasca-persister depends on:

- Zookeeper
- Kafka
- InfluxDB or Vertica

however these dependencies does not need to be installed on the same
hosts.

================================================================================

EOF

%preun
%service_del_preun %{service_name}.service

%postun
%service_del_postun %{service_name}.service

if [ $1 -eq 0 ] ; then
  getent passwd %{username} > /dev/null
  if [ "$?" == "0" ] ; then
      userdel %{username}
  fi
fi

%files
%defattr(-, root, root)

%{_unitdir}/%{service_name}.service
%{_sbindir}/rc%{service_name}

%dir %{persister_cfg_dir}
%dir %{persister_jar_dir}
%{persister_jar_dir}/%{persister_name}.jar

%attr(0750, %{username}, %{groupname}) %dir %{persister_log_dir}
%attr(0640, root, %{groupname}) %%config(noreplace) %{persister_cfg_dir}/%{persister_name}.yaml

%changelog
* Wed May 10 2017 tbechtold@suse.com
- Add 0001-Bugfix-Parse-value_meta-information.patch (bsc#1048688, FATE#323204)
* Mon Apr 24 2017 johannes.grassler@suse.com
- Added patches for supporting InfluxDB 1.1:
  * upgrade-to-influxdb-1.1.patch
  * fix-for-influxdb-1.1.patch
* Thu Apr 20 2017 tbechtold@suse.com
- Fix ENCODING in openstack-monasca-persister.service
* Thu Apr 20 2017 johannes.grassler@suse.com
- Fixed jar installation
* Tue Apr 18 2017 johannes.grassler@suse.com
- Added missing java-1_8_0-openjdk-devel BuildRequire.
- Tightened file permissions.
* Tue Apr 18 2017 johannes.grassler@suse.com
- Add `mvn` executable to PATH in build.sh to fool run_maven.sh
* Thu Apr 13 2017 johannes.grassler@suse.com
- Converted to Tetra based build
* Wed Apr  5 2017 johannes.grassler@suse.com
- Fix rcopenstack-monasca-persister symlink
- Use macro from openstack-macros for user/group creation
- Removed rpm_version/jar_version macros
* Tue Apr  4 2017 tomasz.trebski@ts.fujitsu.com
- Change service name to openstack-monasca-persister, instead
  openstack-monasca-persister-java
* Thu Mar 23 2017 tomasz.trebski@ts.fujitsu.com
- Upgraded jar from https://github.com/FujitsuEnablingSoftwareTechnologyGmbH/monasca-persister/commit/e5d6fd205cf35d1cb95b3776bc507e4f27978467
* Thu Mar 16 2017 johannes.grassler@suse.com
- Renamed package to openstack-monasca-persister
* Mon Mar 13 2017 tomasz.trebski@ts.fujitsu.com
- Added patched monasca-persister [java] capable of working
  with Influx 1.1. JAR was built from
  repo: https://github.com/FujitsuEnablingSoftwareTechnologyGmbH/monasca-persister
  commit: 1dcfaea6718e3404bfcf970c598e25e8e16b7d67
* Mon Feb 13 2017 tomasz.trebski@ts.fujitsu.com
- Replaced %%{word}%% with __{word}__ placeholders for sed operations
  to avoid confusion with RPM macros
* Fri Feb 10 2017 tomasz.trebski@ts.fujitsu.com
- Changed package name to monasca-persister-java to avoid
  conflicts with Python version
* Fri Feb  3 2017 tomasz.trebski@ts.fujitsu.com
- Added jar with monasca-persister java, version 1.2.0
- First working version of the package
* Thu Feb  2 2017 tomasz.trebski@ts.fujitsu.com
- Initial specification for monasca-persister [Java] package
